Struct ResponseInit

pub struct ResponseInit {
    pub status: Option<u16>,
    pub status_text: Option<String>,
    pub headers: Option<Headers>,
}
Configuration for creating responses.

ResponseInit provides options that can be set when creating a new Response. All fields are optional and will use defaults if not specified.

Examples

use fetchttp::{ResponseInit, Headers};

let mut headers = Headers::new();
headers.set("X-Custom-Header", "value").unwrap();

let mut init = ResponseInit::new();
init.status = Some(404);
init.status_text = Some("Not Found".to_string());
init.headers = Some(headers);

Fields

status: Option<u16>

HTTP status code (200-599)

status_text: Option<String>

HTTP status text

headers: Option<Headers>

Response headers

Implementations

Source

impl ResponseInit

pub fn new() -> Self

Create a new empty ResponseInit.

All fields will be None and will use defaults when creating a response.

Examples
use fetchttp::ResponseInit;

let init = ResponseInit::new();
assert!(init.status.is_none());
assert!(init.status_text.is_none());
assert!(init.headers.is_none());